@@ -47,3 +47,40 @@ private:
 };
 
 }
+
+#if (__cplusplus >= 201703L)
+// structured bindings for C++17 and newer
+namespace std
+{
+
+template<>
+struct tuple_size<xs::HashEntry>
+{
+    static constexpr size_t value = 2;
+};
+
+template<>
+struct tuple_element<0, xs::HashEntry>
+{
+    using type = panda::string_view;
+};
+
+template<>
+struct tuple_element<1, xs::HashEntry>
+{
+    using type = xs::Scalar;
+};
+
+}//namespace std
+
+namespace xs {
+
+template<std::size_t Index>
+std::tuple_element_t<Index, xs::HashEntry> get(const xs::HashEntry& he)
+{
+    if constexpr (Index == 0) return he.key();
+    if constexpr (Index == 1) return he.value();
+}
+
+}
+#endif
